@@ -60,7 +60,7 @@ pub(crate) enum Error {
     InvalidPriorConfiguration { msg: String },
     #[error("read position determined from cigar string exceeds record length")]
     ReadPosOutOfBounds,
-    #[error("invalid strand information '{value}', must be '+', '-', or '*'")]
+    #[error("invalid strand information '{value}', must be '+', '-', '*' or '.'")]
     InvalidStrandInfo { value: char },
     #[error("invalid read orientation information '{value}', must be 'F1R2', 'F2R1', etc.")]
     InvalidReadOrientationInfo { value: String },
